/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session } from '@zowe/imperative';
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc';
/**
 * This class holds helper functions that are used to get the content of data sets or USS files through the RSE APIs
 * @export
 * @class Get
 */
export declare class Get {
    /**
     * Retrieve data sets content
     *
     * @param {Session}             session      - RSE connection info
     * @param {string}              dataSetName  - contains the data set name
     * @param {IViewOptions}        [options={}] - contains the options to be sent
     *
     * @returns {Promise<Buffer>} Promise that resolves to the content of the data set
     *
     * @throws {ImperativeError}
     */
    static dataSet(session: Session, dataSetName: string, options: Partial<zowe.IGetOptions>): Promise<IRestApiResponse>;
    static getFileTag(session: Session, USSFileName: string): Promise<string>;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
