/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as imperative from '@zowe/imperative';
import { IHeaderContent } from '../doc/IHeaderContent';
/**
 * This is a simple sleep function to help when waiting for a certain period of
 * time before continuing.
 *
 * @param {number} [ms=1000] The number of milliseconds to sleep.
 *
 * @returns {Promise<void>} Resolves after the specified time is up.
 *
 * @example <caption>Sleeping within code</caption>
 *
 * async function doStuff() {
 *   await CoreUtils.sleep(10000);
 *   console.log("You will see this message 10 seconds after function was entered");
 * }
 */
export declare function sleep(ms?: number): Promise<void>;
/**
 * Execute multiple promises in a pool with a maximum number of promises
 * executing at once
 * @param poolLimit - limit of how many promises should execute at once
 * @param array - array of objects to convert to promises with iteratorFn
 * @param iteratorFn - the function that turns an entry in the array into a promise
 */
export declare function asyncPool(poolLimit: number, array: any[], iteratorFn: (item: any, array: any[]) => Promise<any>): Promise<any>;
export declare function checkForToken(session: imperative.Session): IHeaderContent;
export declare function setUnixRestCommandFullHeaders(session: imperative.Session): IHeaderContent;
export declare function setHeaders(session: imperative.Session): IHeaderContent[];
export declare function getUserHome(): unknown;
export declare function apiVersionCheck(session: imperative.Session, version: number): Promise<void>;
export declare function readLocalFile(filePath: string): Promise<string>;
/**
 *
 * Builds the endpoint for RSE API calls.  The if/else check is for auto-init config files
 * that add '/api/v1' to the basePath.
 * TO DO: adjust this method for v2 paths if changes are made
 *
 * @param {Session}  session      - RSE connection info
 * @param {string}   endpoint     - RSE API endpoint
 *
 * @returns {string} Returns the endpoint for the RSE API calls
 *
 */
export declare function endpointBuilder(session: imperative.Session, endpoint: string): string;
