/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { ICommandArguments, ICommandOptionDefinition, IProfile, ISession } from '@zowe/imperative';
import { RseRestSession } from '../api';
/**
 * Utility Methods for the REST plugin's sessions
 * @export
 */
export declare class RestSessionUtils {
    static REST_CONNECTION_OPTION_GROUP: string;
    /**
     * Option used in profile creation and commands for hostname for REST REST
     */
    static REST_OPTION_HOST: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for port for Zowe REST
     */
    static REST_OPTION_PORT: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for username / ID  for REST
     */
    static REST_OPTION_USER: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for password/passphrase for rest
     */
    static REST_OPTION_PASSWORD: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for rejectUnauthorized setting for connecting to RSE API
     */
    static REST_OPTION_REJECT_UNAUTHORIZED: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for context root or base path for rest
     */
    static REST_OPTION_BASE_PATH: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for context root or base path for rest
     */
    static REST_OPTION_PROTOCOL: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for default encoding options
     */
    static REST_OPTION_ENCODING: ICommandOptionDefinition;
    static REST_OPTION_TOKEN_TYPE: ICommandOptionDefinition;
    static REST_OPTION_TOKEN_VALUE: ICommandOptionDefinition;
    /**
     * Options related to connecting to rest
     * These options can be filled in if the user creates a profile
     */
    static REST_CONNECTION_OPTIONS: ICommandOptionDefinition[];
    /**
     * Given an rest profile, create a REST Client Session.
     * @static
     * @param {IProfile} profile - RSE profile contents
     * @returns {Session} - A session for usage in the RSE REST Client
     */
    static createBasicRestSession(profile: IProfile): RseRestSession;
    /**
     * Given command line arguments, create an session configuration object.
     * @param {IProfile} args - The arguments specified by the user
     * @returns {ISession} - A session configuration to be used for a session.
     */
    static createSessCfgFromArgs(args: ICommandArguments): ISession;
    private static get log();
}
